@@ -43,13 +43,13 @@ test_that("adds empty row if no arguments", {
 test_that("error if adding row with unknown variables", {
   expect_error(
     add_row(tibble(a = 3), xxyzy = "err"),
-    "Can't add row with new variable `xxyzy`",
+    error_inconsistent_new_rows("xxyzy"),
     fixed = TRUE
   )
 
   expect_error(
     add_row(tibble(a = 3), b = "err", c = "oops"),
-    "Can't add row with new variables `b`, `c`",
+    error_inconsistent_new_rows(c("b", "c")),
     fixed = TRUE
   )
 })
@@ -102,7 +102,7 @@ test_that("error if both .before and .after are given", {
   df <- tibble(a = 1:3)
   expect_error(
     add_row(df, a = 4:5, .after = 2, .before = 3),
-    "Can't specify both `.before` and `.after`",
+    error_both_before_after(),
     fixed = TRUE
   )
 })
@@ -115,10 +115,10 @@ test_that("missing row names stay missing when adding row", {
 })
 
 test_that("adding to a list column adds a NULL value (#148)", {
-  expect_null(add_row(data_frame(a = as.list(1:3)))$a[[4]])
-  expect_null(add_row(data_frame(a = as.list(1:3)), .before = 1)$a[[1]])
-  expect_null(add_row(data_frame(a = as.list(1:3)), .after = 1)$a[[2]])
-  expect_null(add_row(data_frame(a = as.list(1:3), b = 1:3), b = 4:6)$a[[5]])
+  expect_null(add_row(tibble(a = as.list(1:3)))$a[[4]])
+  expect_null(add_row(tibble(a = as.list(1:3)), .before = 1)$a[[1]])
+  expect_null(add_row(tibble(a = as.list(1:3)), .after = 1)$a[[2]])
+  expect_null(add_row(tibble(a = as.list(1:3), b = 1:3), b = 4:6)$a[[5]])
 })
 
 test_that("add_row() keeps the class of empty columns", {
@@ -127,9 +127,10 @@ test_that("add_row() keeps the class of empty columns", {
 })
 
 test_that("add_row() fails nicely for grouped data frames (#179)", {
+  skip_if_not_installed("dplyr")
   expect_error(
     add_row(dplyr::group_by(iris, Species), Petal.Width = 3),
-    "Can't add rows to grouped data frames",
+    error_add_rows_to_grouped_df(),
     fixed = TRUE
   )
 })
@@ -172,10 +173,15 @@ test_that("add_column() keeps unchanged if no arguments", {
   expect_identical(iris, add_column(iris))
 })
 
+test_that("add_column() can add to empty tibble or data frame", {
+  expect_identical(add_column(tibble(.rows = 3), a = 1:3), tibble(a = 1:3))
+  expect_identical(add_column(as.data.frame(tibble(.rows = 3)), a = 1:3), data.frame(a = 1:3))
+})
+
 test_that("error if adding existing columns", {
   expect_error(
     add_column(tibble(a = 3), a = 5),
-    "Column `a` already exists",
+    error_duplicate_new_cols("a"),
     fixed = TRUE
   )
 })
@@ -183,7 +189,7 @@ test_that("error if adding existing columns", {
 test_that("error if adding wrong number of rows with add_column()", {
   expect_error(
     add_column(tibble(a = 3), b = 4:5),
-    "`.data` must have 1 row, not 2",
+    error_inconsistent_new_cols(1, data.frame(b = 4:5)),
     fixed = TRUE
   )
 })
@@ -246,7 +252,7 @@ test_that("error if both .before and .after are given", {
   df <- tibble(a = 1:3)
   expect_error(
     add_column(df, b = 4:6, .after = 2, .before = 3),
-    "Can't specify both `.before` and `.after`",
+    error_both_before_after(),
     fixed = TRUE
   )
 })
@@ -255,12 +261,12 @@ test_that("error if column named by .before or .after not found", {
   df <- tibble(a = 1:3)
   expect_error(
     add_column(df, b = 4:6, .after = "x"),
-    "Column `x` not found",
+    error_unknown_names("x"),
     fixed = TRUE
   )
   expect_error(
     add_column(df, b = 4:6, .before = "x"),
-    "Column `x` not found",
+    error_unknown_names("x"),
     fixed = TRUE
   )
 })
