@@ -15,6 +15,18 @@ test_that("format_v for character", {
   expect_equal(format_v(character()), character())
 })
 
+test_that("format_v for factor", {
+  expect_equal(format_v(factor(c("1", "a"))), c("1", "a"))
+  expect_equal(format_v(factor(c("foo", '"bar"'))), c("foo", "\"bar\""))
+  expect_equal(format_v(factor()), character())
+  # Add quotes around factor levels with comma
+  # so they don't appear as if they were two observations (GH 384)
+  expect_equal(
+    format_v(factor(c("foo, bar", "foo", '"bar"'))),
+    paste0('"', c("foo, bar", "foo", "\\\"bar\\\""), '"')
+  )
+})
+
 test_that("format_v for list", {
   expect_equal(format_v(list(1:3)), "[<1, 2, 3>]")
   expect_equal(format_v(as.list(1:3)), "[1, 2, 3]")
@@ -29,6 +41,8 @@ test_that("format_v for list", {
 })
 
 test_that("glimpse output matches known output", {
+  skip_on_os("windows")
+
   expect_output_file_rel(
     glimpse(as_tibble(mtcars), width = 70L),
     "glimpse/mtcars-70.txt"
@@ -79,12 +93,13 @@ test_that("glimpse output matches known output", {
 test_that("glimpse(width = Inf) raises legible error", {
   expect_error(
     glimpse(mtcars, width = Inf),
-    "`width` must be finite",
+    error_glimpse_infinite_width(),
     fixed = TRUE
   )
 })
 
 test_that("glimpse works for structures with unknown rows", {
+  skip_on_os("windows") # capture_output_lines() forces native encoding
   iris2 <- as_unknown_rows(iris)
 
   expect_output_file(
@@ -92,3 +107,38 @@ test_that("glimpse works for structures with unknown rows", {
     output_file("glimpse/iris-70-na-nrow.txt")
   )
 })
+
+test_that("glimpse calls tbl_sum() (#550)", {
+  skip_on_os("windows") # capture_output_lines() forces native encoding
+  iris2 <- as_override_tbl_sum(iris)
+
+  expect_output(
+    glimpse(iris2),
+    "Overridden: tbl_sum",
+    fixed = TRUE
+  )
+})
+
+test_that("glimpse works on nested data (#486)", {
+  skip_on_os("windows")
+
+  nested_iris_df <- tibble(
+    Species = unique(iris$Species),
+    data = unname(split(iris, iris$Species))
+  )
+
+  nested_iris_tbl <- tibble(
+    Species = unique(iris$Species),
+    data = map(unname(split(iris, iris$Species)), as_tibble)
+  )
+
+  expect_output_file_rel(
+    glimpse(nested_iris_df, width = 70L),
+    "glimpse/iris-nested-df-70.txt"
+  )
+
+  expect_output_file_rel(
+    glimpse(nested_iris_tbl, width = 70L),
+    "glimpse/iris-nested-tbl-70.txt"
+  )
+})
